@@ -1,6 +1,9 @@
 setClass("EventAssignment", representation(variable = "character", math = "expression"), 
   contains = "SBase")
 
+setMethod("describe", "EventAssignment",
+          function(object) paste(variable(object), "=", math(object)))
+
  setGeneric("variable", function(object) standardGeneric("variable"))
 setMethod("variable", "EventAssignment", function(object) object@variable)
 
@@ -13,7 +16,7 @@ setReplaceMethod("variable", "EventAssignment", function(object, value) {
 })
 
 setReplaceMethod("math", "EventAssignment", function(object, value) {
-  object@math <- as.expression(value)
+  object@math <- asMath(value)
   object
 })
 
