@@ -1,6 +1,19 @@
 setClass("SBML", representation(level = "integer", ver = "integer", model = "Model"), 
   contains = "SBase", prototype = list(level = as.integer(2), ver = as.integer(1)),
-  validity = function(object) rsbml_check(object))
+  validity = function(object) {
+    doc <- rsbml_doc(object)
+    problems <- rsbml_problems(doc)
+    if (length(fatals(problems)) || length(errors(problems)))
+      as(problems, "character")
+    else NULL
+  })
+
+setMethod("describe", "SBML",
+          function(object) {
+            desc <- paste("SBML Document (level = ", level(object),
+                          ", version = ", ver(object), ")", sep = "")
+            c(desc, describe(model(object)))
+          })
 
 setGeneric("level", function(object) standardGeneric("level"))
 setMethod("level", "SBML", function(object) object@level)
